/** Copyright (C) 2017 by Bundesanstalt für Gewässerkunde
 * Software engineering by
 *  Björnsen Beratende Ingenieure GmbH
 *  Dr. Schumacher Ingenieurbüro für Wasser und Umwelt
 *
 * This file is Free Software under the GNU AGPL (>=v3)
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details.
 */
package org.dive4elements.river.artifacts.uinfo.vegetationzones;

import java.util.ArrayList;
import java.util.Collection;

import org.apache.commons.lang.math.DoubleRange;
import org.dive4elements.artifacts.CallContext;
import org.dive4elements.river.artifacts.access.RiverAccess;
import org.dive4elements.river.artifacts.common.ResultRow;
import org.dive4elements.river.artifacts.model.Calculation;
import org.dive4elements.river.artifacts.model.CalculationResult;
import org.dive4elements.river.artifacts.resources.Resources;
import org.dive4elements.river.artifacts.sinfo.util.CalculationUtils;
import org.dive4elements.river.artifacts.sinfo.util.RiverInfo;
import org.dive4elements.river.artifacts.uinfo.UINFOArtifact;
import org.dive4elements.river.artifacts.uinfo.commons.UInfoResultType;
import org.dive4elements.river.model.River;

/**
 * @author Domenico Nardi Tironi
 *
 */
final class VegetationZonesCalculation {

    private final CallContext context;

    public VegetationZonesCalculation(final CallContext context) {
        this.context = context;
    }

    public CalculationResult calculate(final UINFOArtifact uinfo) {
        final Calculation problems = new Calculation();

        final String calcModeLabel = Resources.getMsg(this.context.getMeta(), uinfo.getCalculationMode().name());
        final String user = CalculationUtils.findArtifactUser(this.context, uinfo);

        final RiverAccess access = new RiverAccess(uinfo);
        final River river = access.getRiver();
        final DoubleRange calcRange = null;
        final RiverInfo riverInfo = new RiverInfo(river);

        final VegetationzonesAccess vAccess = new VegetationzonesAccess(uinfo);
        final ArrayList<String[]> zones = vAccess.getVegZones();

        final VegetationZonesCalculationResults results = new VegetationZonesCalculationResults(calcModeLabel, user, riverInfo, calcRange);

        final Collection<ResultRow> rows = new ArrayList<>();
        for (final String[] zone : zones) {
            final ResultRow row2 = ResultRow.create().//
                    putValue(UInfoResultType.vegname, zone[0]).//
                    putValue(UInfoResultType.vegdauervon, zone[1]).//
                    putValue(UInfoResultType.vegdauerbis, zone[2]);
            rows.add(row2);
        }

        final VegetationZonesCalculationResult result = new VegetationZonesCalculationResult("Ergebnis 1", rows);

        results.addResult(result, problems);

        return new CalculationResult(results, problems);
    }
}